yakumo.nova

Package yakumo :: Package nova |
[hide private]
[frames] | no frames]

# Package nova

source code

Submodules | [hide private]
yakumo.nova.v2: Sub client class for Nova API v2 yakumo.nova.v2.agent: Resource class and its manager for agents in Compute API v2 yakumo.nova.v2.aggregate: Resource class and its manager for aggregates in Compute API v2 yakumo.nova.v2.availability_zone: Resource class and its manager for availability zones in Compute API v2 yakumo.nova.v2.certificate: Resource class and its manager for root certificates in Compute API v2 yakumo.nova.v2.cloudpipe: Resource class and its manager for cloudpipes in Compute API v2 yakumo.nova.v2.fixed_ip: Resource class and its manager for fixed IPs in Compute API v2 yakumo.nova.v2.flavor: Resource class and its manager for flavors in Compute API v2 yakumo.nova.v2.floating_ip: Resource class and its manager for floating IPs in Compute API v2 yakumo.nova.v2.floating_ip_bulk: Resource class and its manager for floating IP bulks in Compute API v2 yakumo.nova.v2.floating_ip_dns: Resource class and its manager for floating IP DNS entries in Compute API v2 yakumo.nova.v2.hypervisor: Resource class and its manager for hypervisors in Compute API v2 yakumo.nova.v2.image: Resource class and its manager for images in Compute API v2 yakumo.nova.v2.interface_attachment: Resource class and its manager for interface attachment in Compute API v2 yakumo.nova.v2.key_pair: Resource class and its manager for key pairs in Compute API v2 yakumo.nova.v2.network: Resource class and its manager for networks in Compute API v2 yakumo.nova.v2.quota_set: Resource class and its manager for Quota sets in Compute API v2 yakumo.nova.v2.security_group: Resource class and its manager for security groups in Compute API v2 yakumo.nova.v2.security_group_default_rule: Resource class and its manager for security group default rules in Compute API v2 yakumo.nova.v2.security_group_rule: Resource class and its manager for security group rules in Compute API v2 yakumo.nova.v2.server: Resource class and its manager for servers in Compute API v2 yakumo.nova.v2.server_group: Resource class and its manager for server groups in Compute API v2 yakumo.nova.v2.service: Resource class and its manager for services in Compute API v2 yakumo.nova.v2.volume_attachment: Resource class and its manager for volume attachment in Compute API v2

Variables | [hide private]
| __package__ = `None`